@@ -20,28 +20,44 @@ from ..help import timing, helping
 class Doist(tyming.Tymist):
     """
     Doist is the root coroutine scheduler
-    Provides relative cycle time in seconds with .tyme property and advanced
-    by .tick method of .tock sized increments.
-    .tyme may be artificial time or real time in seconds.
+    Provides relative cycle time in seconds with .tyme property to doers it runs
+    The relative cycle time is advanced in .tock size increments by the  by  the
+    .tick method.
+    The doist may treat .tyme as artificial time or synchonize it to real time.
 
-    .ply method runs generators once that are synchronized to cycle time .tyme
-           cycle may run as fast as possbile or run in real time.
+    .ready method prepares dogs (doer generators) by calling generator functions
+        or generator methods and assigning to dogs list of tuples.
 
-    .run method continually runs .ply until generators are complete
+    .once method runs its dogs (doer generators) once per invocation.
+        This synchronizes their cycle time .tyme to the Doist's tyme.
 
-    Inherited Attributes:
+
+    .do method repeatedly runs .once until generators are complete
+       it may either repeat as fast as possbile or repeat at real time increments.
+
+    Inherited Class Attributes:
+        .Tock is default .tock
+
+    Attributes:
+        .real is boolean. True means run in real time, Otherwise as fast as possible.
+        .limit is float maximum run tyme limit then closes all doers
+        .timer is MonoTimer for real time intervals
 
     Inherited Properties:
         .tyme is float relative cycle time, .tyme is artificial time
         .tock is float tyme increment of .tick()
 
+    Properties:
+        .tyme is float relative cycle time, .tyme is artificial time
+        .tock is float tyme increment of .tick()
+
     Inherited Methods:
         .tick increments .tyme by one .tock or provided tock
 
-    Attributes:
-        .real is boolean. True means run in real time, Otherwise as fast as possible.
-        .limit is float maximum run tyme limit then closes all doers
-        .timer is MonoTimer for real time intervals
+    Methods:
+        .ready prepare doer generators (dogs)
+        .once  run through dogs one time
+        .do repeadedly call .once until all dogs are complete or times out
 
     """
     def __init__(self, real=False, limit=None, doers=None, **kwa):
@@ -65,13 +81,13 @@ class Doist(tyming.Tymist):
         self.timer = timing.MonoTimer(duration = self.tock)
 
 
-
     def ready(self, doers=None):
         """
         Returns dogs deque of triples (dog, retyme, index)  where:
             dog is generator
-            retyme is tyme in seconds when next should run may be real or simulated
-            index is position of associated doer in .doers list
+            retyme is tyme (real or simulated) in seconds when dog should run next
+            index is position of associated doer in .doers list used to assign
+                .done state to associated doer for dog
 
         Calls each generator callable (function or method) in .doers to create
         each generator dog.
@@ -80,7 +96,9 @@ class Doist(tyming.Tymist):
 
         Parameters:
             doers is list of generator method or function callables with attributes
-                tock, done, and opts dict()
+                .tock is tyme increment in seconds
+                .done is Boolean completion state
+                .opts is dict() of optional parameters
         """
         if doers is not None:
             self.doers = doers
@@ -103,8 +121,9 @@ class Doist(tyming.Tymist):
         Cycle once through dogs deque and update in place
         dogs is deque of triples of (dog, retyme, index) where:
             dog is generator
-            retyme is tyme in seconds when next should run may be real or simulated
-            index is position of associated doer in .doers list
+            retyme is tyme (real or simulated) in seconds when dog should run next
+            index is position of associated doer in .doers list used to assign
+                .done state to associated doer for dog
 
         Each cycle checks all generators in dogs deque and runs if retyme past.
         At end of cycle advances .tyme by one .tock by calling .tick()
@@ -114,7 +133,7 @@ class Doist(tyming.Tymist):
 
             if retyme <= self.tyme:  # run it now
                 try:
-                    tock = dog.send(self.tyme)  #  nothing to send for now
+                    tock = dog.send(self.tyme)  # send tyme
                 except StopIteration as ex:  # returned instead of yielded
                     self.doers[index].done = ex.value if ex.value else False  # assign done state
                 else:  # reappend for next pass
@@ -129,31 +148,32 @@ class Doist(tyming.Tymist):
         """
         Readies dogs deque from .doers or doers if any and then runs .once with
         dogs until completion
-        Each entry in dogs is duple of (dog, retyme) where retyme is tyme in
-            seconds when next should run may be real or simulated
-        Each cycle runs all generators in dogs deque by calling .send on each one.
+        Each entry in dogs is triples (dog, retyme, index)  where:
+            dog is generator
+            retyme is tyme (real or simulated) in seconds when dog should run next
+            index is position of associated doer in .doers list used to assign
+                .done state to associated doer for dog
 
         If interrupted by exception call .close on each dog to force  exit context.
 
         Keyboard interrupt (cntl-c) forces exit.
 
-        Since finally clause closes generators they must be reinited before then
-        can be run again
+        Once finally clause closes a generator it must be reinited
+        before it can be run again
         """
-        if limit is not None:
+        if limit is not None:  # time limt for running if any. useful in test
             self.limit = abs(float(limit))
 
-        if tyme is not None:
+        if tyme is not None:  # initialize starting tyme
             self.tyme = tyme
 
-        dogs = self.ready(doers=doers)  # runs enter context
+        dogs = self.ready(doers=doers)  # runs enter context on each doer
 
         tymer = tyming.Tymer(tymist=self, duration=self.limit)
         self.timer.start()
-        try: #so always clean up resources if exception
-            while True:  # until doers complete or exception
-                try:  #CNTL-C generates keyboardInterrupt to break out of while loop
-
+        try:  # always clean up resources upon exception
+            while True:  # until doers complete or exception or keyboardInterrupt
+                try:
                     self.once(dogs)  # increments .tyme runs recur context
 
                     if self.real:  # wait for real time to expire
@@ -162,12 +182,12 @@ class Doist(tyming.Tymist):
                         self.timer.restart()  #  no time lost
 
                     if self.limit and tymer.expired:
-                        break  # use for testing
+                        break  # break out of forever loop
 
                     if not dogs:  # no more remaining dogs so done
                         break  # break out of forever loop
 
-                except KeyboardInterrupt: # CNTL-C shutdown skedder
+                except KeyboardInterrupt:  # use CNTL-C to shutdown from shell
                     break
 
                 except SystemExit: # Forced shutdown of process
@@ -188,7 +208,7 @@ class Doist(tyming.Tymist):
             while(dogs):  # .close each remaining do in dogs in reverse order
                 dog, retime, index = dogs.pop() #pop it off
                 try:
-                    tock = dog.close()  # force GeneratorExit
+                    tock = dog.close()  # force GeneratorExit. Maybe log exit tock tyme
                 except StopIteration:
                     pass  # Hmm? Not supposed to happen!
                 else:  # set done state
@@ -197,8 +217,12 @@ class Doist(tyming.Tymist):
 
 def doify(f, name=None, tock=0.0, **opts):
     """
-    Converts generator function f into Doist compatible copy, g, and returns g.
+    Returns Doist compatible copy, g, of converted generator function f.
     Each invoction of doify(f) returns a unique copy of doified function f.
+    Imbues copy, g, of converted generator function, f, with attributes used by
+    Doist.ready() or DoDoer.enter().
+    Allows multiple instances of copy, g, of generator function, f, each with
+    unique attributes.
 
     Usage:
     def f():
@@ -208,7 +232,8 @@ def doify(f, name=None, tock=0.0, **opts):
 
     Parameters:
         f is generator function
-        name is new name for returned doified copy g
+        name is new function name for returned doified copy g. Default is to copy
+            f.__name__
         tock is default tock attribute of doified copy g
         opts is dictionary of remaining parameters that becomes .opts attribute
             of doified copy g
@@ -222,7 +247,10 @@ def doify(f, name=None, tock=0.0, **opts):
 
 def doize(tock=0.0, **opts):
     """
-    Decorator that returns Doist compatible decorated generator function.
+    Returns decorator that makes decorated generator function Doist compatible.
+    Imbues decorated generator function with attributes used by Doist.ready() or
+    DoDoer.enter().
+    Only one instance of decorated function with shared attributes is allowed.
 
     Usage:
     @doize
@@ -253,13 +281,11 @@ class Doer(tyming.Tymee):
     Doer is generator creator and has extra methods and attributes that plain
     generator function does not
 
-    Inherited Attributes:
-
     Attributes:
         .done is Boolean completion state:
             True means completed
             Otherwise incomplete. Incompletion maybe due to close or abort.
-        .args is dict of optional parameters injected into .do
+        .opts is dict of injected options into its .do generator by scheduler
 
     Inherited Properties:
         .tyme is float ._tymist.tyme, relative cycle or artificial time
@@ -268,8 +294,10 @@ class Doer(tyming.Tymee):
         .tock is float, desired time in seconds between runs or until next run,
                  non negative, zero means run asap
 
-    Methods:
+    Inherited Methods:
         .wind  injects ._tymist dependency
+
+    Methods:
         .__call__ makes instance callable
             Appears as generator function that returns generator
         .do is generator method that returns generator
@@ -299,7 +327,7 @@ class Doer(tyming.Tymee):
         super(Doer, self).__init__(**kwa)
         self.tock = tock  # desired tyme interval between runs, 0.0 means asap
         self.done = None  #  default completion state
-        self.opts = {}  # used for injection
+        self.opts = {}  # used for injection of options into .do by scheduler
 
 
     def __call__(self, **kwa):
@@ -334,9 +362,11 @@ class Doer(tyming.Tymee):
 
     def do(self, tymist, tock=0.0, **opts):
         """
-        Generator method to run this doer
-        Calling this method returns generator
-        Interface matched generator function for compatibility
+        Generator method to run this doer.
+        Calling this method returns generator.
+        Interface matches generator function for compatibility.
+        To customize create subclasses and override the lifecycle methods:
+            .enter, .recur, .exit, .close, .abort
 
         Parameters:
             tymist is injected Tymist instance with tymist.tyme
@@ -376,20 +406,31 @@ class Doer(tyming.Tymee):
     def enter(self):
         """
         Do 'enter' context actions. Override in subclass. Not a generator method.
+        Set up resources. Comparable to context manager enter.
         """
 
 
     def recur(self, tyme):
         """
         Do 'recur' context actions. Override in subclass.
-        Parameters:
-            tyme is output of send fed to do yield, Doist feeds its .tyme
+        Regular method that perform repetitive actions once per invocation.
+        Assumes resource setup in .enter() and resource takedown in .exit()
+        (see ReDoer for example of .recur that is a generator method)
+
         Returns completion state of recurrence actions.
            True means done False means continue
-        Maybe a non-generator method or a generator method.
-        For base class do:
-            non-generator recur method runs until returns (True)
-            generator recur method runs until returns (yield from)
+
+        Parameters:
+            Doist feeds its .tyme through .send to .do yield which passes it here.
+
+
+        .recur maybe implemented by a subclass either as a non-generator method
+        or a generator method. This stub here is as a non-generator method.
+        The base class .do detects which type:
+            If non-generator .do method runs .recur method once per iteration
+                until .recur returns (True)
+            If generator .do method runs .recur with (yield from) until .recur
+                returns (see ReDoer for example of generator .recur)
 
         """
         return (False)
@@ -398,12 +439,17 @@ class Doer(tyming.Tymee):
     def exit(self):
         """
         Do 'exit' context actions. Override in subclass. Not a generator method.
+        Clean up resources. Comparable to context manager exit.
+        Called by finally after normal return, close, or abort.
+        After .exit() do returns resulting in StopIteration.
         """
 
 
     def close(self):
         """
         Do 'close' context actions. Override in subclass. Not a generator method.
+        Forced close by thrown generator .close() method causing GeneratorExit.
+        .exit() is finally called after .close().
         """
 
 
@@ -412,31 +458,29 @@ class Doer(tyming.Tymee):
         Do 'abort' context actions. Override in subclass. Not a generator method.
         Parameters:
             ex is Exception instance that caused abort.
+        Unexpected exception that results in generator exiting but not GeneratorExit.
+        .exit() is finally called after .abort().
         """
 
 
 class ReDoer(Doer):
     """
-    Example sub class where .recur is generator method not plain method.
-       Doer.do method detects and executes using yield from.
+    ReDoer is an example sub class whose .recur is a generator method not a
+    plain method. Its .do method detects that its .recur is a generator method
+    and executes it using yield from instead of just calling the method.
 
     Inherited Attributes:
         .done is Boolean completion state:
             True means completed
             Otherwise incomplete. Incompletion maybe due to close or abort.
-        .args is dict of optional parameters injected into .do
-
-    Attributes:
-
+        .opts is dict of injected options into its .do generator by scheduler
 
     Inherited Properties:
         .tyme is float ._tymist.tyme, relative cycle or artificial time
         .tock is float, desired time in seconds between runs or until next run,
                  non negative, zero means run asap
 
-    Properties:
-
-    Methods:
+    Inherited Methods:
         .wind  injects ._tymist dependency
         .__call__ makes instance callable
             Appears as generator function that returns generator
@@ -447,15 +491,21 @@ class ReDoer(Doer):
         .close is close context method
         .abort is abort context method
 
+    Overidden Methods:
+        .recur
+
     Hidden:
        ._tymist is Tymist instance reference
        ._tock is hidden attribute for .tock property
+
     """
 
     def recur(self, tyme):
         """
-        Do 'recur' context actions. Override in subclass.
-        This is example of generator method.
+        Do 'recur' context actions as a generator method. Override in subclass.
+        Assumes resource setup in .enter() and resource takedown in .exit()
+        (see Doer for example of .recur that is a regular method)
+
         yield the current .tock
         accepts the current tyme
         returns the .done
@@ -486,29 +536,27 @@ class ReDoer(Doer):
 
 class DoDoer(Doer):
     """
-    DoDoer implements Doist like functionality to allow nesting of Doers.
+    DoDoer implements Doist like functionality to allow nested scheduling of Doers.
     Each DoDoer runs a list of doers like a Doist but using the tyme from its
-       injected tymist
+       injected tymist as injected by its parent DoDoer or Doist.
 
+    Scheduling hierarchy: Doist->DoDoer...->DoDoer->Doers
 
     Inherited Attributes:
         .done is Boolean completion state:
             True means completed
             Otherwise incomplete. Incompletion maybe due to close or abort.
-        .args is dict of optional parameters injected into .do
+        .opts is dict of injected options for its generator .do
 
     Attributes:
         .doers is list of Doers or Doer like generator functions
 
-
     Inherited Properties:
         .tyme is float ._tymist.tyme, relative cycle or artificial time
         .tock is float, desired time in seconds between runs or until next run,
                  non negative, zero means run asap
 
-    Properties:
-
-    Methods:
+    Inherited Methods:
         .wind  injects ._tymist dependency
         .__call__ makes instance callable
             Appears as generator function that returns generator
@@ -519,9 +567,16 @@ class DoDoer(Doer):
         .close is close context method
         .abort is abort context method
 
+    Overidden Methods:
+        .do
+        .enter
+        .recur
+        .exit
+
     Hidden:
        ._tymist is Tymist instance reference
        ._tock is hidden attribute for .tock property
+
     """
 
     def __init__(self, doers=None, **kwa):
@@ -548,7 +603,7 @@ class DoDoer(Doer):
         Parameters:
             tymist is injected Tymist instance with tymist.tyme
             tock is injected initial tock value
-            args is dict of injected optional additional parameters
+            opts is dict of injected optional additional parameters
         """
         try:
             # enter context
@@ -673,7 +728,7 @@ class ServerDoer(Doer):
         .done is Boolean completion state:
             True means completed
             Otherwise incomplete. Incompletion maybe due to close or abort.
-        .args is dict of optional parameters injected into .do
+        .opts is dict of injected options into its .do generator by scheduler
 
     Attributes:
        .server is TCP Server instance
@@ -943,7 +998,7 @@ class WhoDoer(Doer):
         .done is Boolean completion state:
             True means completed
             Otherwise incomplete. Incompletion maybe due to close or abort.
-        .args is dict of optional parameters injected into .do
+        .opts is dict of injected options into its .do generator by scheduler
 
     Attributes:
        .states is list of State namedtuples (tyme, context, feed, count)
@@ -1020,7 +1075,8 @@ class WhoDoer(Doer):
 def whoDo(tymist, tock=0.0, states=None, **opts):
     """
     Generator function test example non-class based generator.
-    Calling this function returns generator
+    Calling this function returns generator.
+    Wrapping this function with doify returns copy with unique attributes
     """
     tyme = tymist.tyme
     count = 0
@@ -1055,7 +1111,7 @@ def whoDo(tymist, tock=0.0, states=None, **opts):
 @doize(tock=0, states=None)
 def exDo(tymist, tock=0.0, states=None, **opts):
     """
-    Generator function example non-class based generator
+    Decorated generator function example non-class based generator
     Calling this function returns generator
     """
     tyme = tymist.tyme
